netapp_ontap.resources.aggregate API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.aggregate`

Copyright © 2020 NetApp Inc. All rights reserved.

## Updating storage aggregates

The PATCH operation is used to modify properties of the aggregate. There are several properties that can be modified on an aggregate. Only one property can be modified for each PATCH request. PATCH operations on the aggregate's disk count will be blocked while one or more nodes in the cluster are simulating or implementing automatic aggregate creation. The following is a list of properties that can be modified using the PATCH operation including a brief description for each:

- name - This property can be changed to rename the aggregate.
- node.name and node.uuid - Either property can be updated in order to relocate the aggregate to a different node in the cluster.
- block_storage.mirror.enabled - This property can be changed from 'false' to 'true' in order to mirror the aggregate, if the system is capable of doing so.
- block_storage.primary.disk_count - This property can be updated to increase the number of disks in an aggregate.
- block_storage.primary.raid_size - This property can be updated to set the desired RAID size.
- block_storage.primary.raid_type - This property can be updated to set the desired RAID type.
- cloud_storage.tiering_fullness_threshold - This property can be updated to set the desired tiering fullness threshold if using FabricPool.
- data_encryption.software_encryption_enabled - This property enables or disables NAE on the aggregate.

### Aggregate expansion

The PATCH operation also supports automatically expanding an aggregate based on the spare disks which are present within the system. Running PATCH with the query "auto_provision_policy" set to "expand" starts the recommended expansion job. In order to see the expected change in capacity before starting the job, call GET on an aggregate instance with the query "auto_provision_policy" set to "expand".

### Manual simulated aggregate expansion

The PATCH operation also supports simulated manual expansion of an aggregate. Running PATCH with the query "simulate" set to "true" and "block_storage.primary.disk_count" set to the final disk count will start running the prechecks associated with expanding the aggregate to the proposed size. The response body will include information on how many disks the aggregate can be expanded to, any associated warnings, along with the proposed final size of the aggregate.

## Deleting storage aggregates

If volumes exist on an aggregate, they must be deleted or moved before the aggregate can be deleted. See the /storage/volumes API for details on moving or deleting volumes.

## Examples

### Retrieving a specific aggregate from the cluster

The following example shows the response of the requested aggregate. If there is no aggregate with the requested UUID, an error is returned.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="870dd9f2-bdfa-4167-b692-57d1cec874d4")
        resource.get()
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "19425837-f2fa-4a9f-8f01-712f626c983c",
            "data_encryption": {
                "drive_protection_enabled": False,
                "software_encryption_enabled": False,
            },
            "home_node": {"name": "node-1", "uuid": "caf95bec-f801-11e8-8af9-005056bbe5c1"},
            "create_time": "2018-12-04T15:40:38-05:00",
            "cloud_storage": {"attach_eligible": False},
            "block_storage": {
                "primary": {
                    "disk_type": "ssd",
                    "disk_count": 6,
                    "raid_size": 24,
                    "checksum_style": "block",
                    "disk_class": "solid_state",
                    "raid_type": "raid_dp",
                },
                "mirror": {"state": "unmirrored", "enabled": False},
                "plexes": [{"name": "plex0"}],
                "hybrid_cache": {"enabled": False},
            },
            "name": "test1",
            "space": {
                "efficiency": {
                    "savings": 1408029,
                    "logical_used": 1646350,
                    "ratio": 6.908119720880661,
                },
                "cloud_storage": {"used": 0},
                "block_storage": {
                    "full_threshold_percent": 98,
                    "available": 191942656,
                    "used": 43061248,
                    "size": 235003904,
                },
                "efficiency_without_snapshots": {
                    "savings": 0,
                    "logical_used": 737280,
                    "ratio": 1.0,
                },
            },
            "state": "online",
            "snaplock_type": "non_snaplock",
            "node": {"name": "node-1", "uuid": "caf95bec-f801-11e8-8af9-005056bbe5c1"},
        }
    )

### Retrieving statistics and metric for an aggregate

In this example, the API returns the "statistics" and "metric" properties for the aggregate requested.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="538bf337-1b2c-11e8-bad0-005056b48388")
        resource.get(fields="statistics,metric")
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "538bf337-1b2c-11e8-bad0-005056b48388",
            "name": "aggr4",
            "statistics": {
                "status": "ok",
                "throughput_raw": {
                    "write": 63771742208,
                    "other": 146185560064,
                    "read": 3106045952,
                    "total": 213063348224,
                },
                "timestamp": "2019-07-08T22:17:09+00:00",
                "iops_raw": {
                    "write": 1137230,
                    "other": 1586535,
                    "read": 328267,
                    "total": 3052032,
                },
                "latency_raw": {
                    "write": 313354426,
                    "other": 477201985,
                    "read": 54072313,
                    "total": 844628724,
                },
            },
            "metric": {
                "status": "ok",
                "duration": "PT15S",
                "latency": {"write": 230, "other": 123, "read": 149, "total": 124},
                "timestamp": "2019-07-08T22:16:45+00:00",
                "throughput": {
                    "write": 840226,
                    "other": 193293789,
                    "read": 7099,
                    "total": 194141115,
                },
                "iops": {"write": 17, "other": 11663, "read": 1, "total": 11682},
            },
        }
    )

For more information and examples on viewing historical performance metrics for any given aggregate, see `DOC /storage/aggregates/{uuid}/metrics`

### Simulating aggregate expansion

The following example shows the response for a simulated data aggregate expansion based on the values of the 'block_storage.primary.disk_count' attribute passed in. The query does not modify the existing aggregate but returns how the aggregate will look after the expansion along with any associated warnings. Simulated data aggregate expansion will be blocked while one or more nodes in the cluster are simulating or implementing automatic aggregate creation. This will be reflected in the following attributes:

- space.block_storage.size - Total usable space in bytes, not including WAFL reserve and aggregate Snapshot copy reserve.
- block_storage.primary.disk_count - Number of disks that could be used to create the aggregate.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="cae60cfe-deae-42bd-babb-ef437d118314")
        resource.block_storage.primary.disk_count = 14
        resource.patch(hydrate=True, simulate=True)

### Retrieving a recommendation for an aggregate expansion

The following example shows the response with the recommended data aggregate expansion based on what disks are present within the system. The query does not modify the existing aggregate but returns how the aggregate will look after the expansion. The recommendation will be reflected in the attributes - 'space.block_storage.size' and 'block_storage.primary.disk_count'. Recommended data aggregate expansion will be blocked while one or more nodes in the cluster are simulating or implementing automatic aggregate creation.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="cae60cfe-deae-42bd-babb-ef437d118314")
        resource.get(auto_provision_policy="expand")
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "cae60cfe-deae-42bd-babb-ef437d118314",
            "block_storage": {
                "primary": {
                    "disk_type": "ssd",
                    "disk_count": 23,
                    "disk_class": "solid_state",
                    "raid_type": "raid_dp",
                },
                "mirror": {"enabled": False},
                "hybrid_cache": {"enabled": False},
            },
            "_links": {
                "self": {
                    "href": "/api/storage/aggregates/cae60cfe-deae-42bd-babb-ef437d118314"
                }
            },
            "name": "node_2_SSD_1",
            "space": {"block_storage": {"size": 1116180480}},
            "node": {
                "name": "node-2",
                "uuid": "4046dda8-f802-11e8-8f6d-005056bb2030",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/4046dda8-f802-11e8-8f6d-005056bb2030"
                    }
                },
            },
        }
    )

### Updating an aggregate in the cluster

The following example shows the workflow of adding disks to the aggregate.
Step 1: Check the current disk count on the aggregate.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="19425837-f2fa-4a9f-8f01-712f626c983c")
        resource.get(fields="block_storage.primary.disk_count")
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "19425837-f2fa-4a9f-8f01-712f626c983c",
            "block_storage": {"primary": {"disk_count": 6}},
            "name": "test1",
        }
    )

Step 2: Update the aggregate with the new disk count in 'block_storage.primary.disk_count'. The response to PATCH is a job unless the request is invalid.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="19425837-f2fa-4a9f-8f01-712f626c983c")
        resource.block_storage.primary.disk_count = 8
        resource.patch()

Step 3: Wait for the job to finish, then call GET to see the reflected change.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="19425837-f2fa-4a9f-8f01-712f626c983c")
        resource.get(fields="block_storage.primary.disk_count")
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "19425837-f2fa-4a9f-8f01-712f626c983c",
            "block_storage": {"primary": {"disk_count": 8}},
            "name": "test1",
        }
    )

The following example shows the workflow to enable software encryption on an aggregate.
Step 1: Check the current software encryption status of the aggregate.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="f3aafdc6-be35-4d93-9590-5a402bffbe4b")
        resource.get(fields="data_encryption.software_encryption_enabled")
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "f3aafdc6-be35-4d93-9590-5a402bffbe4b",
            "data_encryption": {"software_encryption_enabled": False},
            "name": "aggr5",
        }
    )

Step 2: Update the aggregate with the encryption status in 'data_encryption.software_encryption_enabled'. The response to PATCH is a job unless the request is invalid.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="f3aafdc6-be35-4d93-9590-5a402bffbe4b")
        resource.data_encryption.software_encryption_enabled = True
        resource.patch()

Step 3: Wait for the job to finish, then call GET to see the reflected change.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Aggregate

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Aggregate(uuid="f3aafdc6-be35-4d93-9590-5a402bffbe4b")
        resource.get(fields="data_encryption.software_encryption_enabled")
        print(resource)

Try it out

    Aggregate(
        {
            "uuid": "f3aafdc6-be35-4d93-9590-5a402bffbe4b",
            "data_encryption": {"software_encryption_enabled": True},
            "name": "aggr5",
        }
    )

## Classes

`class Aggregate (*args, **kwargs)`

  Allows interaction with Aggregate objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the collection of aggregates for the entire cluster.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `metric.*` * `space.block_storage.inactive_user_data` * `space.footprint` * `statistics.*`

    ### Related ONTAP commands

    - `storage aggregate show`

    ### Learn more

    - `DOC /storage/aggregates`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the aggregate specified by the UUID. This request starts a job and returns a link to that job.

    ### Related ONTAP commands

    - `storage aggregate delete`

    ### Learn more

    - `DOC /storage/aggregates/{uuid}`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the collection of aggregates for the entire cluster.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `metric.*` * `space.block_storage.inactive_user_data` * `space.footprint` * `statistics.*`

    ### Related ONTAP commands

    - `storage aggregate show`

    ### Learn more

    - `DOC /storage/aggregates`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the collection of aggregates for the entire cluster.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `metric.*` * `space.block_storage.inactive_user_data` * `space.footprint` * `statistics.*`

    ### Related ONTAP commands

    - `storage aggregate show`

    ### Learn more

    - `DOC /storage/aggregates`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the aggregate specified by the UUID with the properties in the body. This request starts a job and returns a link to that job.

    ### Related ONTAP commands

    - `storage aggregate add-disks`
    - `storage aggregate mirror`
    - `storage aggregate modify`
    - `storage aggregate relocation start`
    - `storage aggregate rename`

    ### Learn more

    - `DOC /storage/aggregates/{uuid}`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the aggregate specified by the UUID. This request starts a job and returns a link to that job.

    ### Related ONTAP commands

    - `storage aggregate delete`

    ### Learn more

    - `DOC /storage/aggregates/{uuid}`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the aggregate specified by the UUID. The recommend query cannot be used for this operation.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `metric.*` * `space.block_storage.inactive_user_data` * `space.footprint` * `statistics.*`

    ### Related ONTAP commands

    - `storage aggregate show`

    ### Learn more

    - `DOC /storage/aggregates/{uuid}`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the aggregate specified by the UUID with the properties in the body. This request starts a job and returns a link to that job.

    ### Related ONTAP commands

    - `storage aggregate add-disks`
    - `storage aggregate mirror`
    - `storage aggregate modify`
    - `storage aggregate relocation start`
    - `storage aggregate rename`

    ### Learn more

    - `DOC /storage/aggregates/{uuid}`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Automatically creates aggregates based on an optimal layout recommended by the system. Alternatively, properties can be provided to create an aggregate according to the requested specification. This request starts a job and returns a link to that job. POST operations will be blocked while one or more nodes in the cluster are simulating or implementing automatic aggregate creation.

    ### Required properties

    Properties are not required for this API. The following properties are only required if you want to specify properties for aggregate creation: * `name` - Name of the aggregate. * `node.name` or `node.uuid` - Node on which the aggregate will be created. * `block_storage.primary.disk_count` - Number of disks to be used to create the aggregate.

    ### Default values

    If not specified in POST, the following default values are assigned. The remaining unspecified properties will receive system dependent default values. * `block_storage.mirror.enabled` - false * `snaplock_type` - non_snaplock

    ### Related ONTAP commands

    - `storage aggregate auto-provision`
    - `storage aggregate create`

    ### Example:

        POST /api/storage/aggregates {"node": {"name": "node1"}, "name": "test", "block_storage": {"primary": {"disk_count": "10"}}}

    ### Learn more

    - `DOC /storage/aggregates`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class AggregateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Aggregate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `block_storage GET POST PATCH`

    The block_storage field of the aggregate.

  `cloud_storage PATCH`

    The cloud_storage field of the aggregate.

  `create_time GET`

    Timestamp of aggregate creation

    Example: 2018-01-01T16:00:00.000+0000

  `data_encryption GET POST PATCH`

    The data_encryption field of the aggregate.

  `dr_home_node GET POST PATCH`

    The dr_home_node field of the aggregate.

  `home_node GET POST PATCH`

    The home_node field of the aggregate.

  `inactive_data_reporting GET POST PATCH`

    The inactive_data_reporting field of the aggregate.

  `links GET`

    The links field of the aggregate.

  `metric GET`

    The metric field of the aggregate.

  `name GET POST PATCH`

    Aggregate name

    Example: node1_aggr_1

  `node GET POST PATCH`

    The node field of the aggregate.

  `snaplock_type GET POST`

    SnapLock type

    Valid choices:

    - non_snaplock
    - compliance
    - enterprise
  `space GET POST PATCH`

    The space field of the aggregate.

  `state GET`

    Operational state of the aggregate

    Valid choices:

    - online
    - onlining
    - offline
    - offlining
    - relocating
    - unmounted
    - restricted
    - inconsistent
    - failed
    - unknown
  `statistics GET`

    The statistics field of the aggregate.

  `uuid GET`

    Aggregate UUID